@@ -149,6 +149,9 @@ public:
 		static int sip_family;
 		static int sip_tlsmode;
 		static const char *sip_domain;
+		static const char *sip_realm;
+		static unsigned sip_prefix, sip_range;
+		static char session_uuid[40];
 
         callback(int level = 0);
         virtual ~callback();
@@ -172,6 +175,7 @@ public:
 		virtual void start(service *cfg);
 		virtual void stop(service *cfg);
 		virtual void reload(service *cfg);
+		virtual void publish(service *cfg);
     };
     
 	service(const char *name, size_t s = 0);
