@@ -201,13 +201,13 @@ void server::logging(MappedRegistry *rr, const char *reason)
 	process::printlog("%s %s %s\n", reason, rr->userid, (const char *)dt); 
 }
 
-bool server::publish(MappedRegistry *rr, const char *msgtype, const char *event, const char *expires, const char *body)
+bool server::announce(MappedRegistry *rr, const char *msgtype, const char *event, const char *expires, const char *body)
 {
 	linked_pointer<modules::sipwitch> cb = getModules();
 	bool rtn = false;
 
 	while(!rtn && is(cb)) {
-		rtn = cb->publish(rr, msgtype, event, expires, body);
+		rtn = cb->announce(rr, msgtype, event, expires, body);
 		cb.next();
 	}
 	return rtn;
@@ -1113,6 +1113,28 @@ void server::run(const char *user)
 			continue;
 		}
 
+		if(!stricmp(argv[0], "ifup")) {
+			if(argc != 2)
+				goto invalid;
+			process::printlog("server reloading %s\n", (const char *)logtime);
+            reload(user);
+            continue;
+		}
+	
+		if(!stricmp(argv[0], "ifdown")) {
+			if(argc != 2)
+				goto invalid;
+			process::printlog("server reloading %s\n", (const char *)logtime);
+            reload(user);
+            continue;
+		}
+
+		if(!stricmp(argv[0], "drop")) {
+			if(argc != 2)
+				goto invalid;
+            continue;
+		}
+
 		if(!stricmp(argv[0], "trace")) {
 			if(argc != 2)
 				goto invalid;
