@@ -731,13 +731,15 @@ bool thread::authorize(void)
 		goto local;
 
 	request_address.set(uri_host, local_port);
-	stack::getInterface((struct sockaddr *)&iface, request_address.getAddr());
 
 	if(request_address.getAddr() == NULL) {
+		process::errlog(ERRLOG, "unresolvable request: %s", uri_host);	
 		error = SIP_ADDRESS_INCOMPLETE;
 		goto invalid;
 	}
 
+	stack::getInterface((struct sockaddr *)&iface, request_address.getAddr());
+
 	if(local_port != stack::sip_port)
 		goto remote;
 
@@ -1069,6 +1071,8 @@ void thread::send_reply(int error)
 	case CALL:
 		eXosip_call_build_answer(sevent->tid, error, &reply);
 		if(reply != NULL) {
+			if(stack::sip_protocol == IPPROTO_UDP)
+				osip_message_set_require(reply, "100rel");
 			stack::siplog(reply);
 			eXosip_call_send_answer(sevent->tid, error, reply);
 		}
@@ -1079,6 +1083,8 @@ void thread::send_reply(int error)
 	case MESSAGE:
 		eXosip_message_build_answer(sevent->tid, error, &reply);
 		if(reply != NULL) {
+			if(stack::sip_protocol == IPPROTO_UDP)
+				osip_message_set_require(reply, "100rel");
 			stack::siplog(reply);
 			eXosip_message_send_answer(sevent->tid, error, reply);
 		}
